summaryrefslogtreecommitdiff
path: root/girepository/gitypelib-internal.h
diff options
context:
space:
mode:
authorJohan Dahlin <johan@gnome.org>2010-08-31 17:36:06 -0300
committerJohan Dahlin <johan@gnome.org>2010-08-31 17:37:10 -0300
commit7af39d0ff23d5a8c2316536b864f576f9a2bebc6 (patch)
tree6b10e6277ed3f9f8f24d458f88030b14f5101da4 /girepository/gitypelib-internal.h
parent6379b8a497e2bf8c5b09e37ded88c7a28483389d (diff)
downloadgobject-introspection-7af39d0ff23d5a8c2316536b864f576f9a2bebc6.tar.gz
[GIRepository] Rename GTypelib to GITypelib
Keep a typedef for backwards compatibility, until the major bindings has moved over.
Diffstat (limited to 'girepository/gitypelib-internal.h')
-rw-r--r--girepository/gitypelib-internal.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/girepository/gitypelib-internal.h b/girepository/gitypelib-internal.h
index d1461fa1..87a18170 100644
--- a/girepository/gitypelib-internal.h
+++ b/girepository/gitypelib-internal.h
@@ -1085,9 +1085,9 @@ typedef struct {
} AttributeBlob;
/**
- * GTypelib:
+ * GITypelib:
*/
-struct _GTypelib {
+struct _GITypelib {
/* <private> */
guchar *data;
gsize len;
@@ -1097,7 +1097,7 @@ struct _GTypelib {
gboolean open_attempted;
};
-DirEntry *g_typelib_get_dir_entry (GTypelib *typelib,
+DirEntry *g_typelib_get_dir_entry (GITypelib *typelib,
guint16 index);
void g_typelib_check_sanity (void);
@@ -1106,14 +1106,14 @@ void g_typelib_check_sanity (void);
/**
- * GTypelibError:
+ * GITypelibError:
* @G_TYPELIB_ERROR_INVALID: the typelib is invalid
* @G_TYPELIB_ERROR_INVALID_HEADER: the typelib header is invalid
* @G_TYPELIB_ERROR_INVALID_DIRECTORY: the typelib directory is invalid
* @G_TYPELIB_ERROR_INVALID_ENTRY: a typelib entry is invalid
* @G_TYPELIB_ERROR_INVALID_BLOB: a typelib blob is invalid
*
* A error set while validating the #GTypelib
*/
typedef enum
{
@@ -1122,13 +1122,13 @@ typedef enum
G_TYPELIB_ERROR_INVALID_DIRECTORY,
G_TYPELIB_ERROR_INVALID_ENTRY,
G_TYPELIB_ERROR_INVALID_BLOB
-} GTypelibError;
+} GITypelibError;
#define G_TYPELIB_ERROR (g_typelib_error_quark ())
GQuark g_typelib_error_quark (void);
-gboolean g_typelib_validate (GTypelib *typelib,
+gboolean g_typelib_validate (GITypelib *typelib,
GError **error);
@@ -1106,14 +1106,14 @@ void g_typelib_check_sanity (void);
* @G_TYPELIB_ERROR_INVALID_BLOB: a typelib blob is invalid
*
- * A error set while validating the #GTypelib
+ * A error set while validating the #GITypelib
*/
typedef enum